@@ -30,6 +30,9 @@ class EssbasicClient(AbstractClient):
         """指定需要批量撤销的签署流程Id，批量撤销合同
         客户指定需要撤销的签署流程Id，最多100个，超过100不处理；
 
+        可以撤回：未全部签署完成
+         不可以撤回：已全部签署完成、已拒签、已过期、已撤回、拒绝填写、已解除等合同状态。
+
         **满足撤销条件的合同会发起异步撤销流程，不满足撤销条件的合同返回失败原因。**
 
         **合同撤销成功后，会通过合同状态为 CANCEL 的回调消息通知调用方 [具体可参考回调消息](https://qian.tencent.com/developers/scenes/partner/callback_data_types#-%E5%90%88%E5%90%8C%E7%8A%B6%E6%80%81%E9%80%9A%E7%9F%A5---flowstatuschange)**
@@ -109,7 +112,10 @@ class EssbasicClient(AbstractClient):
         """指定需要批量撤销的签署流程Id，获取批量撤销链接 - 不建议使用此接口，可使用ChannelBatchCancelFlows
         客户指定需要撤销的签署流程Id，最多100个，超过100不处理；
         接口调用成功返回批量撤销合同的链接，通过链接跳转到电子签小程序完成批量撤销;
-        可以撤回：未全部签署完成；不可以撤回（终态）：已全部签署完成、已拒签、已过期、已撤回。
+
+        可以撤回：未全部签署完成
+         不可以撤回：已全部签署完成、已拒签、已过期、已撤回、拒绝填写、已解除等合同状态。
+
         注意:
         能撤回合同的只能是合同的发起人或者发起企业的超管、法人
 
@@ -504,6 +510,29 @@ class EssbasicClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ChannelCreateWebThemeConfig(self, request):
+        """生成页面主题配置
+
+        :param request: Request instance for ChannelCreateWebThemeConfig.
+        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateWebThemeConfigRequest`
+        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateWebThemeConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ChannelCreateWebThemeConfig", params, headers=headers)
+            response = json.loads(body)
+            model = models.ChannelCreateWebThemeConfigResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ChannelDeleteRoleUsers(self, request):
         """通过此接口，删除员工绑定的角色，支持以电子签userId、客户系统userId两种方式调用。
 
